.. vim: set fileencoding=utf-8 :
.. author: Manuel Günther <manuel.guenther@idiap.ch>
.. date: Thu Sep 20 11:58:57 CEST 2012

.. This file contains all links we use for documentation in a centralized place

.. _facereclib: http://pypi.python.org/pypi/facereclib
.. _idiap: http://www.idiap.ch
.. _gitlab: http://gitlab.idiap.ch/bob
.. _bob: http://www.idiap.ch/software/bob
.. _installation: https://www.idiap.ch/software/bob/install
.. _idiap at gitlab: http://gitlab.idiap.ch/bob
.. _at&t database: http://www.cl.cam.ac.uk/research/dtg/attarchive/facedatabase.html
.. _bob's gitlab page: http://gitlab.idiap.ch/bob
.. _buildout: http://www.buildout.org
.. _nist: http://www.nist.gov/itl/iad/ig/focs.cfm
.. _pypi: http://pypi.python.org
.. _sge: http://wiki.idiap.ch/linux/SunGridEngine
.. _csu face recognition resources: http://www.cs.colostate.edu/facerec
.. _xfacereclib.extension.csu: http://pypi.python.org/pypi/xfacereclib.extension.CSU
.. _virtualbox: https://www.virtualbox.org
.. _hdf5: http://www.hdfgroup.org/HDF5
.. _Voxforge: http://www.voxforge.org/
.. _TIMIT: http://www.ldc.upenn.edu/Catalog/catalogEntry.jsp?catalogId=LDC93S1
.. _logistic regression: http://en.wikipedia.org/wiki/Logistic_regression
.. _spear: https://pypi.python.org/pypi/bob.bio.spear
.. _Spro: https://gforge.inria.fr/projects/spro
.. _HTK: http://htk.eng.cam.ac.uk/
.. _bob.db.mobio: https://pypi.python.org/pypi/bob.db.mobio
.. _NIST: http://www.nist.gov/itl/iad/ig/focs.cfm
.. _speechbrain: https://huggingface.co/speechbrain/spkrec-ecapa-voxceleb
